@@ -23,20 +23,20 @@ from datetime import datetime, timedelta, timezone
 
 import click
 import zmq
+from elasticsearch.dsl import Q
 from elasticsearch.exceptions import ConflictError
-from elasticsearch_dsl import Q
 from flask.config import Config
 from tabulate import tabulate
 
-from zubbi import default_settings
-from zubbi import ZUBBI_SETTINGS_ENV
+from zubbi import ZUBBI_SETTINGS_ENV, default_settings
 from zubbi.models import (
     AnsibleRole,
-    get_elasticsearch_parameters_from_config,
     GitRepo,
-    init_elasticsearch_con,
     ZuulJob,
     ZuulTenant,
+    get_elasticsearch_parameters_from_config,
+    init_elasticsearch_con,
+    init_elasticsearch_documents,
 )
 from zubbi.scraper.connections.gerrit import GerritConnection
 from zubbi.scraper.connections.git import GitConnection
@@ -49,7 +49,6 @@ from zubbi.scraper.repos.github import GitHubRepository
 from zubbi.scraper.scraper import Scraper
 from zubbi.scraper.tenant_parser import TenantParser
 
-
 LOGGER = logging.getLogger(__name__)
 
 CONNECTIONS = {
@@ -68,7 +67,7 @@ def configure_logger(verbosity):
     console_handler = logging.StreamHandler()
     console_handler.setLevel(logging.DEBUG)
     log_formatter = logging.Formatter(
-        "%(asctime)s %(levelname)s [%(name)s] %(message)s", datefmt="%Y-%m-%dT%H:%M:%SZ"
+        "%(asctime)s %(levelname)s [%(name)s] %(message)s"
     )
     console_handler.setFormatter(log_formatter)
 
@@ -292,6 +291,7 @@ def init_connections(config):
     # Initialize Elasticsearch connection
     es_config = get_elasticsearch_parameters_from_config(config)
     init_elasticsearch_con(**es_config)
+    init_elasticsearch_documents()
 
     connections = {}
     for con_name, con_data in config["CONNECTIONS"].items():
@@ -556,14 +556,22 @@ def _scrape_repo_map(
 
 
 def scrape_repo(repo, tenants, reusable_repos, scrape_time):
-    job_files, role_files = Scraper(repo).scrape()
+    job_files, role_files = Scraper(
+        repo,
+        tenants.get("extra_config_paths", {}),
+    ).scrape()
 
-    is_rusable_repo = repo.repo_name in reusable_repos
+    is_reusable_repo = repo.repo_name in reusable_repos
     jobs = []
     roles = []
     try:
         jobs, roles = RepoParser(
-            repo, tenants, job_files, role_files, scrape_time, is_rusable_repo
+            repo,
+            tenants,
+            job_files,
+            role_files,
+            scrape_time,
+            is_reusable_repo,
         ).parse()
     except Exception:
         LOGGER.exception("Unable to parse job or role definitions in repo '%s'", repo)
