@@ -14,12 +14,12 @@
 
 import logging
 import os
+from collections import defaultdict
 
 import yaml
 
 from zubbi.scraper.exceptions import CheckoutError, ScraperConfigurationError
 
-
 TENANTS_DIRECTORY = "tenants"
 
 LOGGER = logging.getLogger(__name__)
@@ -62,7 +62,12 @@ class TenantParser:
             self.tenants.append(tenant_name)
 
     def _update_repo_map(self, project, connection_name, tenant):
-        project_name, exclude = self._extract_project(project)
+        result = self._extract_project(project)
+        if result is None:
+            return
+
+        # Extract tuple values from result
+        project_name, exclude, extra_config_paths = result
 
         # Map the current tenant to the current repository
         repo_tenant_entry = self.repo_map.setdefault(
@@ -71,18 +76,60 @@ class TenantParser:
         )
 
         # Update repo_tenant mapping
-        if "jobs" not in exclude:
+        if "job" not in exclude:
             repo_tenant_entry["tenants"]["jobs"].append(tenant)
         repo_tenant_entry["tenants"]["roles"].append(tenant)
 
+        if extra_config_paths:
+            repo_tenant_extra_config_paths = repo_tenant_entry["tenants"].setdefault(
+                "extra_config_paths", defaultdict(lambda: [])
+            )
+            for extra_config_path in extra_config_paths:
+                repo_tenant_extra_config_paths[extra_config_path].append(tenant)
+
     def _extract_project(self, project):
+        # This covers the default case where a project is a simple string
         project_name = project
         exclude = []
+        extra_config_paths = []
+        # If a project is a dictionary, we have to look up and evaluate
+        # certain attributes:
         if type(project) is dict:
             # Get the first key of the dict containing the project name.
+            # NOTE: The dict should only contain a single key since each
+            # project is a dict entry in a list.
             project_name = list(project.keys())[0]
-            exclude = project.get("exclude", [])
-        return project_name, exclude
+
+            if "projects" in project:
+                # TODO (felix): This is kind of a "reverse" structure,
+                # which is usually used to include/exclude the same
+                # configuration items for a lot of projects.
+                # This use case is currently not covered in Zubbi, but
+                # we might want to implement this later on.
+                #
+                # Examples:
+                #
+                # # Include nothing from projects foo, bar
+                # - include: []
+                #   projects:
+                #     - foo
+                #     - bar
+                #
+                # # Exclude jobs and semaphores from foo
+                # - exclude:
+                #     - job
+                #     - semaphore
+                #   projects:
+                #     - foo
+                return
+
+            exclude = project[project_name].get("exclude", [])
+            # NOTE (swietlicki): directories in extra-config-path section contain
+            # trailing slash, while inside the Scraper.iterate_directory() the comparison
+            # is done against dir names without trailing slash
+            for item in project[project_name].get("extra-config-paths", []):
+                extra_config_paths.append(item[:-1] if item.endswith("/") else item)
+        return project_name, exclude, extra_config_paths
 
     def _load_tenant_sources_from_file(self, sources_file):
         LOGGER.info("Parsing tenant sources file '%s'", sources_file)
